<?php
session_start();

include('database.php');

// AJAX handler for customer search
if (isset($_GET['search_customers'])) {
    $query = "%" . $_GET['search_customers'] . "%";

    $stmt = $conn->prepare("SELECT id, first_name, last_name FROM users WHERE CONCAT(first_name, ' ', last_name) LIKE ? LIMIT 10");
    $stmt->bind_param("s", $query);
    $stmt->execute();
    $result = $stmt->get_result();

    $customers = [];
    while ($row = $result->fetch_assoc()) {
        $customers[] = [
            'id' => $row['id'],
            'name' => $row['first_name'] . ' ' . $row['last_name']
        ];
    }

    echo json_encode($customers);
    exit(); // Stop further execution for AJAX requests
}

if (!isset($_SESSION['user_id'])) {
    // If the user is not logged in, redirect to login page
    header("Location: login.php");
    exit();
}
// Handle AJAX request for transaction details
if (isset($_GET['transaction_id'])) {
  $transaction_id = $_GET['transaction_id'];

  // Query to get transaction data by ID
  $stmt = $conn->prepare("SELECT transactions.id, transactions.asset, transactions.transaction_type, transactions.amount, transactions.status, transactions.rejection_reason, transactions.date_time, users.first_name, users.last_name 
                          FROM transactions
                          JOIN users ON transactions.user_id = users.id
                          WHERE transactions.id = ? LIMIT 1");
  $stmt->bind_param("i", $transaction_id);
  $stmt->execute();
  $result = $stmt->get_result();
  
  $transaction = $result->fetch_assoc();

  if ($transaction) {
      echo json_encode($transaction);
  } else {
      echo json_encode(['error' => 'Transaction not found']);
  }

  exit(); // Stop further execution for AJAX request
}
$user_id = $_SESSION['user_id'];

$stmt = $conn->prepare("SELECT first_name, last_name FROM users WHERE id = ?");
$stmt->bind_param("i", $user_id); 
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $user = $result->fetch_assoc();
    $first_name = $user['first_name'];
    $last_name = $user['last_name'];
} else {
    header("Location: login.php");
    exit();
}

// Fetch transactions with customer names
$transactionQuery = $conn->prepare("SELECT transactions.id, transactions.asset, transactions.transaction_type, transactions.amount, transactions.status, transactions.rejection_reason, transactions.date_time, users.first_name, users.last_name 
                                    FROM transactions
                                    JOIN users ON transactions.user_id = users.id
                                    ORDER BY transactions.date_time DESC LIMIT 10");
$transactionQuery->execute();
$transactionResult = $transactionQuery->get_result();

$transactions = [];
while ($transaction = $transactionResult->fetch_assoc()) {
    $transactions[] = [
        'id' => $transaction['id'],
        'customer_name' => $transaction['first_name'] . ' ' . $transaction['last_name'],
        'asset' => $transaction['asset'],
        'transaction_type' => $transaction['transaction_type'],
        'amount' => $transaction['amount'],
        'status' => $transaction['status'],
        'rejection_reason' => $transaction['rejection_reason'],
        'date_time' => $transaction['date_time']
    ];  
}

// Close connections
$transactionQuery->close();
$stmt->close();
$conn->close();
?>



<!DOCTYPE html>
<html lang="en">

<head>
  <!-- required meta -->
  <meta charset="UTF-8" />
  <meta http-equiv="X-UA-Compatible" content="IE=edge" />
  <meta name="viewport" content="width=device-width, initial-scale=1.0" />
  <!-- #keywords -->
  <meta name="keywords" content="boot, Bootstrap, Forex and Stock Broker HTML Template" />
  <!-- #description -->
  <meta name="description" content="Forex and Stock Broker HTML Template" />
  <!-- #title -->
  <title>Admin Panel - Transactions</title>
  <!-- #favicon -->
  <link rel="shortcut icon" href="assets/images/fav.png" type="image/x-icon" />
  <!-- ==== css dependencies start ==== -->
  <link href="https://cdn.quilljs.com/1.3.6/quill.snow.css" rel="stylesheet" />
  <link rel="stylesheet" href="assets/css/style.min.css" />
</head>

<body>
  <!--  Preloader  -->
  <div class="preloader">
    <span class="loader"></span>
  </div>
  <!-- end preloader -->

  <!-- Scroll To Top Start-->
  <button class="scrollToTop d-none d-md-flex d-center rounded" aria-label="scroll Bar Button">
    <i class="mat-icon fs-four nb4-color ti ti-arrow-up"></i>
  </button>
  <!-- Scroll To Top End -->

  <!-- header-section start -->

  <div class="two-column_logo d-none gap-3">
    <a href="dashboard.php">
      <img src="assets/images/text_logo.png" class="logo_light" alt="Logo " />
      <img src="assets/images/text_logo_dark.png" class="logo_dark" alt="Logo" />
    </a>
    <span class="material-symbols-outlined close_nav p-1 d-xl-none">
      close
    </span>
  </div>

  <div class="manu-wrapper">
    <!--header-section start-->
    <header class="top-menu">
      <nav
        class="top-menu__content py-5 py-xxl-8 px-3 px-lg-4 px-xxl-6 d-flex align-items-center justify-content-between gap-6">
        <div class="top-menu__left d-flex gap-3 gap-xxl-6">
          </div>
        </div>
      </nav>
    </header>

    <!-- aside start -->
    <div class="company-logo d-center justify-content-between gap-2">
      <a href="dashboard.php" class="logo_area">
        <span class="logo-xl">
          <img src="assets/images/logo_light.png" class="full_logo" alt="Logo" />
          <img src="assets/images/short_logo_light.png" class="short_logo" alt="Logo" />
        </span>
        <span class="logo-xl logo_dark">
          <img src="assets/images/logo_dark.png" class="full_logo" alt="Logo" />
          <img src="assets/images/short_logo_dark.png" class="short_logo" alt="Logo" />
        </span>
      </a>
      <span class="material-symbols-outlined close_nav p-1 d-xl-none">
        close
      </span>
    </div>

    <aside class="aside-wrapper">
      <div class="main-menu">
        <ul class="main-menu__part">
          <li class="main-menu__title fw-semibold">Admin Panel</li>
          <li class="nav_item">
          <a href="admin_customers.php" class="nav_link">
              <span class="material-symbols-outlined fs-four-up">
                house
              </span>
              <span class="nav_text">Customers</span>
            </a>
            <a href="admin_customers_transactions.php" class="nav_link">
              <span class="material-symbols-outlined fs-four-up">
                money
              </span>
              <span class="nav_text">Transactions</span>
            </a>
          </li>
        <ul class="main-menu__part">
          <li class="main-menu__title fw-semibold"></li>
          <li>
            <a href="logout.html" class="nav_link">
              <span class="material-symbols-outlined p1-color fs-four-up">
                logout
              </span>
              <span href="log_out.html" class="nav_text">Log out</span>
            </a>
          </li>
        </ul>

        <ul class="main-menu__part logout_area mt-auto d-none">
          <li>
            <a href="logout.html"><span class="material-symbols-outlined p1-color">
                logout
              </span></a>
          </li>
        </ul>

      </div>
    </aside>

    <!-- aside end -->
  </div>
  <div class="clone_area d-center"></div>
  <!-- header-section end -->

  <!-- header-section end -->

<!-- Transaction Table -->
<div class="main-content overflow-hidden">
  <div class="container-fluid">
    <div class="col-12">
      <div class="table-area overview_list n0-bg cus-rounded-1 p-4 p-lg-6 cus-border h-100">
        <div class="header-part d-flex flex-nowrap justify-content-between align-items-center gap-8 row-gap-3 pb-5 pb-xxl-6 mb-5 mb-xxl-6">
          <div class="d-flex align-items-center flex-wrap row-gap-3 gap-6 gap-xxl-8 w-100">
            <h4 class="fw-semibold">Transactions</h4>
          </div>
          <div class="d-flex align-items-center gap-3">
            <input type="text" id="searchInput" class="form-control" placeholder="Search Transactions" onkeyup="searchTransactions()">
            <button class="btn btn-success" onclick="showAddTransactionModal()">Add Transaction</button>
          </div>
        </div>
        <div class="table-main">
          <table id="transactionTable">
            <thead>
              <tr>
                <th>Customer Name</th>
                <th>Asset</th>
                <th>Transaction Type</th>
                <th>Amount</th>
                <th>Status</th>
                <th>Rejection Reason</th>
                <th>Date Time</th>
                <th>Edit</th>
                <th>Delete</th>
              </tr>
            </thead>
            <tbody>
              <?php
              foreach ($transactions as $transaction) {
                echo "<tr>
                  <td><span class='fw-medium'>{$transaction['customer_name']}</span></td>
                  <td><span class='fw-medium'>{$transaction['asset']}</span></td>
                  <td><span class='fw-medium'>{$transaction['transaction_type']}</span></td>
                  <td><span class='fw-medium'>{$transaction['amount']}</span></td>
                  <td><span class='fw-medium'>{$transaction['status']}</span></td>
                  <td><span class='fw-medium'>{$transaction['rejection_reason']}</span></td>
                  <td><span class='fw-medium'>{$transaction['date_time']}</span></td>
                  <td>
                    <button onclick=\"editTransaction({$transaction['id']})\" 
                      class='btn_box btn_alt cus-border border-color py-2 py-lg-3 px-4 w-100'>
                      Edit
                    </button>
                  </td>
                  <td>
                    <button onclick=\"deleteTransaction({$transaction['id']})\" 
                      class='btn_box btn_alt cus-border border-color py-2 py-lg-3 px-4 w-100'>
                      Delete
                    </button>
                  </td>
                </tr>";
              }
              ?>
            </tbody>
          </table>
        </div>
      </div>
    </div>
  </div>
</div>

<!-- Change Transaction Status Modal -->
<div id="changeTransactionStatusModal" class="modal" style="display:none; position:fixed; top:0; left:0; width:100%; height:100%; z-index:1000;">
  <div class="modal-content" style="position:relative; background-color:#fff; padding:20px; width: 400px; margin: auto; top: 50%; transform: translateY(-50%); border-radius: 10px; box-shadow: 0 4px 8px rgba(0,0,0,0.2);">
    <span class="close-btn" onclick="closeChangeTransactionStatusModal()" style="position:absolute; top:10px; right:15px; font-size: 25px; cursor:pointer; color: #333; transition: color 0.3s;">&times;</span>
    <h2 style="text-align:center; color: #333; font-family: 'Arial', sans-serif; font-size: 24px;">Change Transaction Status</h2>
    <form id="changeTransactionStatusForm">
        <!-- Transaction Information -->
        <div class="form-group" style="margin-bottom:15px;">
        <label for="transaction_id" style="font-size:14px; color:#555;">Transaction ID</label>
        <input type="text" id="transaction_id" name="transaction_id" class="form-control" style="width:100%; padding:10px; margin-top:5px; border-radius:5px; border:1px solid #ddd;" readonly>
        </div>

        <!-- Change Status -->
    
        <div class="form-group" style="margin-bottom:15px;">
            <label for="status" style="font-size:16px; font-weight: bold; color:#555;">Change Status</label>
            <select id="status" name="status" class="form-control" style="width:100%; padding:10px; margin-top:5px; border-radius:5px; border:1px solid #ddd;" required onchange="toggleRejectionReason()">
            <option value="Successful">Successful</option>
            <option value="Pending">Pending</option>
            <option value="Rejected">Rejected</option>
            </select>
        </div>

        <!-- Rejection Reason -->
        <div class="form-group" style="margin-bottom:15px; display:none;" id="rejectionReasonGroup">
            <label for="rejection_reason" style="font-size:14px; color:#555;">Rejection Reason (optional)</label>
            <textarea id="rejection_reason" name="rejection_reason" class="form-control" style="width:100%; padding:10px; margin-top:5px; border-radius:5px; border:1px solid #ddd; height:100px;"></textarea>
        </div>

        <!-- Submit Button -->
        <button type="submit" class="btn btn-primary" style="padding:10px 20px; background-color:#007bff; color:#fff; border:none; cursor:pointer; border-radius:5px; width:100%;">Submit</button>
    </form>
  </div>
</div>
<!-- Change Transaction Status Modal End -->
 <script>
    var transactions = <?php echo json_encode($transactions); ?>;
    var transactionSelected = null;
// Function to close the modal
function closeChangeTransactionStatusModal() {
  document.getElementById("changeTransactionStatusModal").style.display = "none";
}

// Function to toggle the rejection reason input visibility based on the status selected
function toggleRejectionReason() {
  const status = document.getElementById("status").value;
  const rejectionReasonGroup = document.getElementById("rejectionReasonGroup");

  if (status === "Rejected") {
    rejectionReasonGroup.style.display = "block";
  } else {
    rejectionReasonGroup.style.display = "none";
  }
}

// Placeholder function to simulate fetching transaction data by ID
// Replace this with an actual data fetching mechanism (e.g., AJAX request)
function getTransactionData(transactionId) {
  // Sample data, replace with real data from your backend
    transactionSelected = transactions.find(transaction => transaction.id == transactionId);
    return transactionSelected;
//     console.log('ja_transactions', transaction);
//   return {
//     id: transactionId,
//     status: "Pending", // This could be 'Successful', 'Pending', or 'Rejected'
//     rejection_reason: "", // This will be empty unless status is 'Rejected'
//   };
}
</script>


<!-- Add Transaction Modal -->


<form id="addTransactionModal" class="modal" style="display:none; position:fixed; top:0; left:0; width:100%; height:100%; z-index:1000;">
  <div class="modal-content" style="position:relative; background-color:#fff; padding:20px; width: 400px; margin: auto; top: 50%; transform: translateY(-50%); border-radius: 10px; box-shadow: 0 4px 8px rgba(0,0,0,0.2);">
    <span class="close-btn" onclick="closeAddTransactionModal()" style="position:absolute; top:10px; right:15px; font-size: 25px; cursor:pointer; color: #333; transition: color 0.3s;">&times;</span>
    <h2 style="text-align:center; color: #333; font-family: 'Arial', sans-serif; font-size: 24px;">Add Transaction</h2>

    <!-- Customer Name Input with Search -->
    <div class="form-group" style="margin-bottom:15px;">
      <label for="customer_name" style="font-size:14px; color:#555;">Customer Name</label>
      <input type="hidden" id="customer_id" name="customer_id" />
      <input type="text" id="customer_name" name="customer_name" class="form-control" style="width:100%; padding:10px; margin-top:5px; border-radius:5px; border:1px solid #ddd;" placeholder="Search Customer..." onkeyup="searchCustomers()" required>
      <ul id="customerDropdown" class="dropdown-list" style="position:absolute; max-height:150px; overflow-y:auto; width:100%; background-color:white; border:1px solid #ddd; display:none; border-radius:5px; z-index:1000;"></ul> <!-- Dropdown for customer names -->
    </div>

    <div>
      <!-- Asset -->
      <div class="form-group" style="margin-bottom:15px;">
        <label for="asset" style="font-size:16px; font-weight: bold; color:#555;">Asset</label>
        <select id="asset" name="asset" class="form-control" style="width:100%; padding:10px; margin-top:5px; border-radius:5px; border:1px solid #ddd;" required>
          <option value="BTC">BTC</option>
          <option value="ETH">ETH</option>
          <option value="TRX">TRX</option>
          <option value="USDT">USDT</option>
        </select>
      </div>

      <!-- Amount -->
      <div class="form-group" style="margin-bottom:15px;">
        <label for="amount" style="font-size:14px; color:#555;">Amount</label>
        <input id="amount" name="amount" class="form-control" style="width:100%; padding:10px; margin-top:5px; border-radius:5px; border:1px solid #ddd;" required />
      </div>

      <!-- Transaction Type -->
      <div class="form-group" style="margin-bottom:15px;">
        <label for="transaction_type" style="font-size:16px; font-weight: bold; color:#555;">Transaction Type</label>
        <select id="transaction_type" name="transaction_type" class="form-control" style="width:100%; padding:10px; margin-top:5px; border-radius:5px; border:1px solid #ddd;" required>
          <option value="Deposit">Deposit</option>
          <option value="Withdrawal">Withdrawal</option>
        </select>
      </div>
      <!-- Status -->
      <div class="form-group" style="margin-bottom:15px;">
        <label for="status" style="font-size:16px; font-weight: bold; color:#555;">Status</label>
        <select id="status" name="status" class="form-control" style="width:100%; padding:10px; margin-top:5px; border-radius:5px; border:1px solid #ddd;" required>
          <option value="Successful">Successful</option>
          <option value="Pending">Pending</option>
          <option value="Rejected">Rejected</option>
        </select>
      </div>

      <!-- Rejection Reason -->
      <div class="form-group" style="margin-bottom:15px;">
        <label for="rejection_reason" style="font-size:14px; color:#555;">Rejection Reason (optional)</label>
        <textarea id="rejection_reason" name="rejection_reason" class="form-control" style="width:100%; padding:10px; margin-top:5px; border-radius:5px; border:1px solid #ddd; height:100px;"></textarea>
      </div>

      <!-- Submit Button -->
      <button type="submit" class="btn btn-primary" style="padding:10px 20px; background-color:#007bff; color:#fff; border:none; cursor:pointer; border-radius:5px; width:100%;">Submit</button>
</div>
  </div>
</form>
  </div>
</div>

  <!-- ==== js dependencies start ==== -->
  <script src="assets/js/components.js"></script>
  <script src="assets/js/plugins/plugins.js"></script>
  <script src="assets/js/plugins/apexcharts.min.js"></script>
  <script src="https://cdn.quilljs.com/1.3.6/quill.js"></script>
  <script src="assets/js/plugins/custom_apexcharts.js"></script>
  <script src="assets/js/plugins/plugin-custom.js"></script>
  <script src="assets/js/main.js"></script>
  <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>

    <script>
        // Function to open the modal and populate it with transaction details
        function editTransaction(transactionId) {
        // Fetch transaction data using the transactionId (this can be done via AJAX or any method you prefer)
        // For demonstration, we use placeholder values
        const transactionData = getTransactionData(transactionId); // Replace with actual data fetching
        console.log('ja_transationdata', transactionData);
        // Populate the modal with the transaction data
        document.getElementById("transaction_id").value = transactionData.id;
        document.getElementById("status").value = transactionData.status;
        $('#status').val(transactionData.status).niceSelect('update');
        document.getElementById("rejection_reason").value = transactionData.rejection_reason || '';

        // Show the modal
        document.getElementById("changeTransactionStatusModal").style.display = "block";
        }


        document.getElementById("changeTransactionStatusForm").addEventListener("submit", function(event) {
            event.preventDefault();
            $.ajax({
                type: 'POST',
                url: 'post.php',
                data: {
                    action: 'change_transaction_status',
                    data: $('#changeTransactionStatusForm').serialize(),
                },
                success: function () {
                    alert('Saved successfully!');
                    location.reload();
                }
            });
        });

        document.getElementById("addTransactionModal").addEventListener("submit", function(event) {
            event.preventDefault();
            $.ajax({
                type: 'POST',
                url: 'post.php',
                data: {
                    action: 'add_transaction',
                    data: $('#addTransactionModal').serialize(),
                },
                success: function (json) {
                    if(json) {
                      const response = JSON.parse(json);
                      if(response.status === 'error') {
                        alert(response.message);
                      } else {
                        alert('Saved successfully!');
                        location.reload();
                      }
                    }
                    // alert('Saved successfully!');
                }
            });
        });
    </script>
</body>

</html>