<?php
session_start();
include('database.php');

// If the user is not logged in, redirect to login page
if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit();
}

$user_id = $_SESSION['user_id'];

$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $user_id); 
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $user = $result->fetch_assoc();
    $first_name = $user['first_name'];
    $last_name = $user['last_name'];
    $email = $user['email'];
    $phone = $user['phone'];
    $account_type = $user['account_type'];
    $country = $user['country'];
    $address1 = $user['address1'];
    $address2 = $user['address2'];
    $zip_code = $user['zip_code'];
    $id_verification_status = $user['id_verification_status'];
    $bank_verification_status = $user['bank_verification_status'];
    $created_at = $user['created_at'];
} else {
    header("Location: login.php");
    exit();
}

// Initialize message variables
$success_message = '';
$error_message = '';

// Handle the password change form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['old_password'], $_POST['new_password'], $_POST['confirm_password'])) {
        $old_password = $_POST['old_password'];
        $new_password = $_POST['new_password'];
        $confirm_password = $_POST['confirm_password'];

        // Check if the old password matches the stored password
        if (password_verify($old_password, $user['password'])) {
            if ($new_password === $confirm_password) {
                // Hash the new password
                $hashed_password = password_hash($new_password, PASSWORD_DEFAULT);

                // Update the password in the database
                $update_stmt = $conn->prepare("UPDATE users SET password = ? WHERE id = ?");
                $update_stmt->bind_param("si", $hashed_password, $user_id);
                $update_stmt->execute();

                if ($update_stmt->affected_rows > 0) {
                    $_SESSION['message'] = "Password updated successfully!";
                    $_SESSION['message_type'] = "success";
                } else {
                    $_SESSION['message'] = "Failed to update the password.";
                    $_SESSION['message_type'] = "error";
                }
                $update_stmt->close();
            } else {
                $_SESSION['message'] = "New password and confirm password do not match.";
                $_SESSION['message_type'] = "error";
            }
        } else {
            $_SESSION['message'] = "Old password is incorrect.";
            $_SESSION['message_type'] = "error";
        }
    } else {
        $_SESSION['message'] = "Form data not received properly.";
        $_SESSION['message_type'] = "error";
    }
}

$stmt->close();
$conn->close();
?>

<!DOCTYPE html>
<html lang="en">

<head>
  <!-- required meta -->
  <meta charset="UTF-8" />
  <meta http-equiv="X-UA-Compatible" content="IE=edge" />
  <meta name="viewport" content="width=device-width, initial-scale=1.0" />
  <!-- #keywords -->
  <meta name="keywords" content="boot, Bootstrap, Forex and Stock Broker HTML Template" />
  <!-- #description -->
  <meta name="description" content="Forex and Stock Broker HTML Template" />
  <!-- #title -->
  <title>Crypto Porfolio - Change Password</title>
  <!-- #favicon -->
  <link rel="shortcut icon" href="assets/images/fav.png" type="image/x-icon" />
  <!-- ==== css dependencies start ==== -->
  <link href="https://cdn.quilljs.com/1.3.6/quill.snow.css" rel="stylesheet" />
  <link href="https://cdn.jsdelivr.net/npm/sweetalert2@11.7.0/dist/sweetalert2.min.css" rel="stylesheet">

  <link rel="stylesheet" href="assets/css/style.min.css" />
</head>

<body>
  <!--  Preloader  -->
  <div class="preloader">
    <span class="loader"></span>
  </div>
  <!-- end preloader -->

  <!-- Scroll To Top Start-->
  <button class="scrollToTop d-none d-md-flex d-center rounded" aria-label="scroll Bar Button">
    <i class="mat-icon fs-four nb4-color ti ti-arrow-up"></i>
  </button>
  <!-- Scroll To Top End -->

  <!-- header-section start -->

  <div class="two-column_logo d-none gap-3">
    <a href="dashboard.php">
      <img src="assets/images/text_logo.png" class="logo_light" alt="Logo " />
      <img src="assets/images/text_logo_dark.png" class="logo_dark" alt="Logo" />
    </a>
    <span class="material-symbols-outlined close_nav p-1 d-xl-none">
      close
    </span>
  </div>

  <div class="manu-wrapper">
    <!--header-section start-->
    <header class="top-menu">
      <nav
        class="top-menu__content py-5 py-xxl-8 px-3 px-lg-4 px-xxl-6 d-flex align-items-center justify-content-between gap-6">
        <div class="top-menu__left d-flex gap-3 gap-xxl-6">
          <button class="nav_tab d-center cus-rounded-2 left d-none d-md-flex">
            <span class="material-symbols-outlined fs-two n700-color">
              menu
            </span>
          </button>
          <button class="nav_tab second p1-bg d-center cus-rounded-2 left">
            <span class="navbar-toggle-btn box_15 overflow-hidden cus-border-dashed rounded-circle d-md-none">
              <span></span>
              <span></span>
              <span></span>
              <span></span>
            </span>
          </button>
          <div class="company-short-logo d-center justify-content-between gap-2 d-xl-none">
            <a href="dashboard.php" class="logo_area">
              <span class="logo-xl">
                <img src="assets/images/short_logo_light.png" class="logo" alt="Logo" />
              </span>
              <span class="logo-xl logo_dark">
                <img src="assets/images/short_logo_dark.png" class="logo" alt="Logo" />
              </span>
            </a>
          </div>
          <div class="d-flex align-items-center gap-3">
            <form method="POST" class="search__form_nav d-none d-md-flex">

            </form>
          </div>
        </div>
        <div class="top-menu__right d-flex gap-1 gap-md-3 gap-xxl-6 z-0 align-items-center">
          <div class="btn_box btn_alt box_12 cus-border nav_search_short d-md-none">
            <span class="material-symbols-outlined fs-four"> search </span>
          </div>
          <div class="toggle-switch btn_box btn_alt box_12 cus-border">
            <input type="checkbox" class="checkbox" id="checkbox" />
            <label for="checkbox" class="checkbox-label">
              <span class="material-symbols-outlined fs-four">
                dark_mode
              </span>
              <span class="material-symbols-outlined fs-four light_mode">
                light_mode
              </span>
            </label>
          </div>
          <div class="position-relative notification_area">
            <div class="notification_icon btn_box btn_alt box_12 cus-border d-center">
              <span class="material-symbols-outlined fs-four">
                notifications
              </span>
            </div>
            <ul class="notification_nav hover-scroll d-flex flex-column gap-4 n0-bg px-4 px-lg-5 py-4 cus-rounded-1">
              <li>
                <div class="d-flex align-items-center gap-3">
                  <a href="#" class="user_profile_thumb">
                    <img src="assets/images/user_profile10.png" class="rounded-circle" alt="image" />
                  </a>
                  <div class="user_profile_title flex-fill">
                    <a href="#">Theresa Webb</a>
                    <p class="mt-1 fs-eight">just ideas for next time</p>
                  </div>
                  <div class="notification just_active d-center flex-column">
                    <span class="notification__count box_6 rounded-circle d-center fs-eight">5</span>
                    <span class="notification__time fs-eight">4m</span>
                  </div>
                </div>
              </li>
              <li>
                <div class="d-flex align-items-center gap-3">
                  <a href="#" class="user_profile_thumb">
                    <img src="assets/images/user_profile9.png" class="rounded-circle" alt="image" />
                  </a>
                  <div class="user_profile_title flex-fill">
                    <a href="#">Bessie Cooper</a>
                    <p class="mt-1 fs-eight">omg, this is amazing</p>
                  </div>
                  <div class="notification just_active d-center flex-column">
                    <span class="notification__count box_6 rounded-circle d-center fs-eight">1</span>
                    <span class="notification__time fs-eight">5m</span>
                  </div>
                </div>
              </li>
            </ul>
          </div>

          <div class="lang_nav box_12 position-relative cus-border rounded-3">
            <div onclick="toggleDropNav()" class="nav_dropdown_btn btn_box btn_alt box_12 d-center bg1-opty">
              <img src="assets/images/unitedkingdom.png" alt="United Kingdom" class="flag-img rounded-circle box_6" />
              <span class="nav_lang d-none">United Kingdom</span>
            </div>
            <ul class="lang_nav_list hover-scroll position-absolute py-1 py-lg-2 n0-bg cus-rounded-1">
              <li onclick="selectOptionNav('United Kingdom', 'assets/images/united-kingdom.png')"
                class="d-flex align-items-center gap-2 px-3 px-lg-5 py-2">
                <img src="assets/images/unitedkingdom.png" alt="United Kingdom" class="flag-img rounded-circle box_5" />
                <span class="nav_lang">United Kingdom</span>
              </li>
              <li onclick="selectOptionNav('Canada', 'assets/images/canada.png')"
                class="d-flex align-items-center gap-2 px-3 px-lg-5 py-2">
                <img src="assets/images/canada.png" alt="Canada" class="flag-img rounded-circle box_5" />
                <span class="nav_lang">Canada</span>
              </li>
              <li onclick="selectOptionNav('Australia', 'assets/images/australia.png')"
                class="d-flex align-items-center gap-2 px-3 px-lg-5 py-2">
                <img src="assets/images/australia.png" alt="Australia" class="flag-img rounded-circle box_5" />
                <span class="nav_lang">Australia</span>
              </li>
              <li onclick="selectOptionNav('France', 'assets/images/france.png')"
                class="d-flex align-items-center gap-2 px-3 px-lg-5 py-2">
                <img src="assets/images/france.png" alt="France" class="flag-img rounded-circle box_5" />
                <span class="nav_lang">France</span>
              </li>
            </ul>
          </div>


          <div class="user-account box_12 position-relative">
            <div class="profile-nav">
              <img src="assets/images/user.png" class="box_12 cus-rounded-1" alt="img" />
            </div>
            <ul class="user-profile hover-scroll n0-bg d-flex flex-column gap-1 p-3 cus-rounded-1">
              <li>
                <a href="settings.php" class="d-flex align-items-center gap-2 p1-color"><span
                    class="material-symbols-outlined fs-four">
                    person </span>My Account</a>
              </li>
              <li>
                <a href="log_out.html class=" d-flex align-items-center gap-2 p1-color"><span
                    class="material-symbols-outlined fs-four">
                    logout </span>Log Out</a>
              </li>
            </ul>
          </div>
        </div>
      </nav>
    </header>

    <!-- aside start -->
    <div class="company-logo d-center justify-content-between gap-2">
      <a href="dashboard.php" class="logo_area">
        <span class="logo-xl">
          <img src="assets/images/logo_light.png" class="full_logo" alt="Logo" />
          <img src="assets/images/short_logo_light.png" class="short_logo" alt="Logo" />
        </span>
        <span class="logo-xl logo_dark">
          <img src="assets/images/logo_dark.png" class="full_logo" alt="Logo" />
          <img src="assets/images/short_logo_dark.png" class="short_logo" alt="Logo" />
        </span>
      </a>
      <span class="material-symbols-outlined close_nav p-1 d-xl-none">
        close
      </span>
    </div>

    <aside class="aside-wrapper">
      <div class="main-menu">
        <ul class="main-menu__part">
          <li class="main-menu__title fw-semibold">Dashboard</li>
          <li class="nav_item">
            <a href="dashboard.php" class="nav_link">
              <span class="material-symbols-outlined fs-four-up">
                house
              </span>
              <span class="nav_text">Dashboard</span>
            </a>
          </li>
          <li class="nav_item">
            <a href="wallet.php" class="nav_link">
              <span class="material-symbols-outlined fs-four-up">
                layers
              </span>
              <span class="nav_text">Wallets</span>
            </a>
          </li>
          <li class="nav_dropdown">
            <button class="dropdown_arrow">
              <span class="material-symbols-outlined fs-four-up">
                account_circle
              </span>
              <span class="nav_text">Account</span>
            </button>
            <ul class="nav_dropdown-menu">
              <li><a href="settings.php">Settings</a></li>
              <li><a href="password.php">Password</a></li>
            </ul>
          </li>
          <li class="nav_item">
            <a href="contact.html" class="nav_link">
              <span class="material-symbols-outlined fs-four-up">
                phone
              </span>
              <span class="nav_text">Contact Us</span>
            </a>
          </li>
        </ul>
        <ul class="main-menu__part">
          <li class="main-menu__title fw-semibold"></li>
          <li>
            <a href="logout.html" class="nav_link">
              <span class="material-symbols-outlined p1-color fs-four-up">
                logout
              </span>
              <span href="log_out.html" class="nav_text">Log out</span>
            </a>
          </li>
        </ul>

        <ul class="main-menu__part logout_area mt-auto d-none">
          <li>
            <a href="logout.html"><span class="material-symbols-outlined p1-color">
                logout
              </span></a>
          </li>
        </ul>

      </div>
    </aside>

    <!-- aside end -->
  </div>
  <div class="clone_area d-center"></div>
  <!-- header-section end -->

  <!-- main-body start -->
  <div class="main-content">
    <div class="container-fluid">
      <div class="row">
        <div class="col-12">
          <div class="top-area flex-wrap d-center justify-content-between gap-8 row-gap-3">
            <h2>Password</h2>
          </div>
        </div>
      </div>


      <!--Change Password Form -->
      <div class="row">
        <div class="col-12">
          <div class="n0-bg cus-rounded-1 p-4 p-lg-6 cus-border h-100">
            <div
              class="header-part d-flex flex-wrap justify-content-between align-items-center gap-8 row-gap-3 pb-5 pb-xxl-6 mb-5 mb-xxl-6">
              <h4 class="fw-semibold">Change Password</h4>
            </div>
            <form action="password.php" method="POST" class="d-flex flex-column gap-5 gap-lg-6">
              <div class="row g-5 g-lg-6">
                <div class="col-sm-6">
                  <div class="single-input">
                    <label class="fs-six-up fw-medium mb-2 mb-sm-4" for="old_password">Old Password</label>
                    <div class="input-pass">
                      <input type="password" class="fs-seven py-2 py-sm-3 ps-3 ps-sm-5 ps-lg-6 pe-10 pe-lg-13"
                        id="old_password" name="old_password" placeholder="Old Password" required />
                      <span class="password-eye-icon"></span>
                    </div>
                  </div>
                </div>
                <div class="col-sm-6">
                  <div class="single-input">
                    <label class="fs-six-up fw-medium mb-2 mb-sm-4" for="npassword">New Password</label>
                    <div class="input-pass">
                      <input type="password" class="fs-seven py-2 py-sm-3 ps-3 ps-sm-5 ps-lg-6 pe-10 pe-lg-13"
                        id="npassword" name="new_password" placeholder="New Password" required />
                      <span class="password-eye-icon"></span>
                    </div>
                  </div>
                </div>
              </div>
              <div class="single-input">
                <label class="fs-six-up fw-medium mb-2 mb-sm-4" for="conf_password">Confirm Password</label>
                <div class="input-pass">
                  <input type="password" class="fs-seven py-2 py-sm-3 ps-3 ps-sm-5 ps-lg-6 pe-10 pe-lg-13"
                    id="conf_password" name="confirm_password" placeholder="Confirm Password" required />
                  <span class="password-eye-icon"></span>
                </div>
              </div>
              <div class="d-flex gap-5 gap-lg-6 pt-4">
                <button type="submit"
                  class="btn_box py-2 py-lg-3 px-5 px-lg-6 cus-rounded-1 cus-border border-color">Save Change</button>
              </div>
            </form>
          </div>
        </div>
      </div>

      <?php
// Show SweetAlert message after form submission
if (isset($_SESSION['message'])) {
    $message = $_SESSION['message'];
    $message_type = $_SESSION['message_type'];

    // Clear the session message after displaying it
    unset($_SESSION['message']);
    unset($_SESSION['message_type']);
    ?>
      <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11.7.0/dist/sweetalert2.min.js"></script>
      <script>
        Swal.fire({
          icon: '<?php echo $message_type; ?>',
          title: '<?php echo $message; ?>',
          showConfirmButton: true
        });
      </script>
      <?php } ?>

      <div class="row">
        <div class="col-12">
          <div class="two-factor n0-bg cus-rounded-1 p-4 p-lg-6 cus-border h-100">
            <div
              class="header-part d-flex flex-wrap justify-content-between align-items-center gap-8 row-gap-3 pb-5 pb-xxl-6 mb-5 mb-xxl-6">
              <h4 class="fw-semibold">Two-Factor Authentication</h4>
            </div>
            <div class="d-flex flex-wrap flex-sm-nowrap gap-5 gap-lg-15 w-100">
              <div class="separator_line_dashed right pe-sm-5 pe-lg-15 d-flex flex-column gap-5 gap-lg-6 flex-fill">
                <div class="d-center justify-content-between gap-6">
                  <div class="d-flex flex-column gap-2">
                    <span class="fw-medium fs-six-up">Email Notifications</span>
                    <span class="fs-seven">Receive notification Via Email</span>
                  </div>
                  <div class="form-check form-switch d-flex align-items-center">
                    <input class="form-check-input" type="checkbox" name="switch_make_public" checked />
                  </div>
                </div>
              </div>
              <div class="d-flex flex-column gap-5 gap-lg-6 flex-fill">
                <div class="d-center justify-content-between gap-6">
                  <div class="d-flex flex-column gap-2">
                    <span class="fw-medium fs-six-up">SMS Notifications</span>
                    <span class="fs-seven">Receive notifications via sms</span>
                  </div>
                  <div class="form-check form-switch d-flex align-items-center">
                    <input class="form-check-input" type="checkbox" name="switch_make_public" />
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
  <!-- main end -->


  <!-- Footer Area Start -->
  <footer class="footer">
    <div class="col-12">
      <div class="footer__copyright justify-content-center justify-content-sm-between gap-10 row-gap-2">
        <p class="copyright text-center">
          Copyright © <span id="copyYear"></span>
          <a href="https://themeforest.net/user/uiaxis" class="p1-color">FinVista</a>. All Rights Reserved
        </p>
        <ul class="footer__copyright-conditions">
          <li><a href="terms-service.html">Privacy policy</a></li>
          <li><a href="terms-service.html">Terms & Conditions</a></li>
        </ul>
      </div>
    </div>
  </footer>
  <!-- Footer Area End -->

  <!-- ==== js dependencies start ==== -->
  <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11.7.0/dist/sweetalert2.min.js"></script>
  <script src="assets/js/plugins/plugins.js"></script>
  <script src="assets/js/plugins/apexcharts.min.js"></script>
  <script src="https://cdn.quilljs.com/1.3.6/quill.js"></script>
  <script src="assets/js/plugins/custom_apexcharts.js"></script>
  <script src="assets/js/plugins/plugin-custom.js"></script>
  <script src="assets/js/main.js"></script>
</body>

</html>