<?php
// Include the database connection
include('database.php');

// Initialize variables
$first_name = $last_name = $email = $phone = $password = $confirm_password = "";

// Handle form submission
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Get form data
    $first_name = $_POST['fname'];
    $last_name = $_POST['lname'];
    $email = $_POST['email_ad'];
    $phone = $_POST['phonenumber_ad'];
    $password = $_POST['password10'];
    $confirm_password = $_POST['confirm_password'];

    // Check if passwords match
    if ($password !== $confirm_password) {
        $popup_type = "error";
        $popup_message = "Passwords do not match! Please check your input.";
    } else {
        // Check if email already exists
        $email_check_query = "SELECT * FROM Users WHERE email = ?";
        $stmt = $conn->prepare($email_check_query);
        $stmt->bind_param("s", $email);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows > 0) {
            // Email already exists
            $popup_type = "error";
            $popup_message = "The email address is already registered. Please try a different one.";
        } else {
            // Hash the password for security
            $hashed_password = password_hash($password, PASSWORD_DEFAULT);

            // Prepare the insert statement
            $stmt = $conn->prepare("INSERT INTO Users (first_name, last_name, email, phone, password) VALUES (?, ?, ?, ?, ?)");
            $stmt->bind_param("sssss", $first_name, $last_name, $email, $phone, $hashed_password);

            // Execute the query and check for success
            if ($stmt->execute()) {
                // Registration successful
                $popup_type = "success";
                $popup_message = "Registration successful! Redirecting to login page...";
                header("refresh:2;url=login.php"); // Redirect after 2 seconds
            } else {
                // Error during registration
                $popup_type = "error";
                $popup_message = "Error: " . $stmt->error;
            }
        }

        // Close the statement
        $stmt->close();
    }
}

// Close the database connection
$conn->close();
?>

<!DOCTYPE html>
<html lang="en">

<head>
    <!-- required meta -->
    <meta charset="UTF-8" />
    <meta http-equiv="X-UA-Compatible" content="IE=edge" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <meta name="keywords" content="Crypto Portfolio - Sign Up" />
    <meta name="description" content="Crypto Portfolio - Sign Up" />
    <title>Crypto Portfolio - Sign Up</title>
    <link rel="shortcut icon" href="assets/images/fav.png" type="image/x-icon" />
    <link href="https://cdn.quilljs.com/1.3.6/quill.snow.css" rel="stylesheet" />
    <link rel="stylesheet" href="assets/css/style.min.css" />

    <!-- Add SweetAlert2 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/sweetalert2@11.7.2/dist/sweetalert2.min.css" rel="stylesheet">
</head>

<body>
    <!--  Preloader -->
    <div class="preloader">
        <span class="loader"></span>
    </div>

    <!-- Scroll To Top -->
    <button class="scrollToTop d-none d-md-flex d-center rounded" aria-label="scroll Bar Button">
        <i class="mat-icon fs-four nb4-color ti ti-arrow-up"></i>
    </button>

    <div class="toggle-switch btn_box btn_alt box_12 cus-border d-none">
        <input type="checkbox" class="checkbox" id="checkbox" />
        <label for="checkbox" class="checkbox-label">
            <span class="material-symbols-outlined fs-four"> dark_mode </span>
            <span class="material-symbols-outlined fs-four light_mode"> light_mode </span>
        </label>
    </div>

    <div class="sign_area login_bg n0-bg d-flex justify-content-center align-items-center">
        <div class="container">
            <div class="row align-items-center justify-content-between">
                <div class="d-none d-md-flex col-md-6 col-lg-5 col-xxl-4 justify-content-end">
                    <div class="login_thumb">
                        <img src="assets/images/signup.png" class="max-xxl-un" alt="image" />
                    </div>
                </div>
                <div class="col-md-6 col-lg-6">
                    <div class="sign__content ms-md-5 ms-xxl-0 pt-120 pb-120">
                        <div class="head_part d-flex flex-column gap-4">
                            <h3>Let’s Get Started!</h3>
                            <p>Kindly complete the registration process to gain access to your cryptocurrency portfolio.</p>
                        </div>
                        <form class="contact__form mt-8 mt-lg-10" method="POST" id="signupForm">
                            <div class="d-flex flex-column gap-5">
                                <div class="row g-5 g-lg-6">
                                    <div class="col-lg-6">
                                        <div class="single-input">
                                            <label class="fs-six-up fw-medium mb-2 mb-sm-4" for="fname">First Name</label>
                                            <input type="text" class="fs-seven py-2 py-lg-3 px-3 px-lg-6" id="fname" name="fname" placeholder="First Name" required />
                                        </div>
                                    </div>
                                    <div class="col-lg-6">
                                        <div class="single-input">
                                            <label class="fs-six-up fw-medium mb-2 mb-sm-4" for="lname">Last Name</label>
                                            <input type="text" class="fs-seven py-2 py-lg-3 px-3 px-lg-6" id="lname" name="lname" placeholder="Last Name" required />
                                        </div>
                                    </div>
                                </div>
                                <div class="single-input">
                                    <label class="fs-six-up fw-medium mb-2 mb-sm-4" for="email_ad">Enter Your Email</label>
                                    <input type="email" class="fs-seven py-2 py-lg-3 px-3 px-lg-6" id="email_ad" name="email_ad" placeholder="Enter Your Email..." required />
                                </div>
                                <div class="single-input">
                                    <label class="fs-six-up fw-medium mb-2 mb-sm-4" for="phonenumber_ad">Enter Your Phone Number</label>
                                    <input type="number" class="fs-seven py-2 py-lg-3 px-3 px-lg-6" id="phonenumber_ad" name="phonenumber_ad" placeholder="Enter Your Phone number..." required />
                                </div>
                                <div class="single-input">
                                    <label class="fs-six-up fw-medium mb-2 mb-sm-4" for="password10">Enter New Password</label>
                                    <div class="input-pass">
                                        <input type="password" class="fs-seven py-2 py-sm-3 ps-3 ps-sm-5 ps-lg-6 pe-10 pe-lg-13" id="password10" name="password10" placeholder="New Password" required />
                                        <span class="password-eye-icon"></span>
                                    </div>
                                </div>
                                <div class="single-input">
                                    <label class="fs-six-up fw-medium mb-2 mb-sm-4" for="confirm_password">Confirm Your Password</label>
                                    <div class="input-pass">
                                        <input type="password" class="fs-seven py-2 py-sm-3 ps-3 ps-sm-5 ps-lg-6 pe-10 pe-lg-13" id="confirm_password" name="confirm_password" placeholder="Confirm Password" required />
                                        <span class="password-eye-icon"></span>
                                    </div>
                                </div>

                                <div class="single-input">
                                    <div class="g-recaptcha" data-sitekey="your-recaptcha-site-key"></div>
                                </div>
                                <p>Have an account? <a href="login.php" class="p1-color fw-semibold">Sign In</a></p>
                            </div>

                            <div class="d-flex gap-5 gap-lg-6 mt-7 mt-lg-8">
                                <button type="submit" class="btn_box py-2 py-lg-3 px-5 px-lg-6 cus-rounded-1 cus-border border-color">
                                    Sign Up
                                </button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <?php if (isset($popup_type) && isset($popup_message)): ?>
        <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11.7.2/dist/sweetalert2.all.min.js"></script>
        <script>
            Swal.fire({
                icon: '<?php echo $popup_type; ?>',
                title: '<?php echo $popup_message; ?>',
                showConfirmButton: false,
                timer: 2000 // Auto-close after 2 seconds
            });
        </script>
    <?php endif; ?>

    <!-- Your existing JavaScript code -->
    <script src="assets/js/plugins/plugins.js"></script>
    <script src="assets/js/plugins/apexcharts.min.js"></script>
    <script src="https://cdn.quilljs.com/1.3.6/quill.js"></script>
    <script src="assets/js/plugins/custom_apexcharts.js"></script>
    <script src="assets/js/plugins/plugin-custom.js"></script>
    <script src="assets/js/main.js"></script>
</body>

</html>
